@@ -21,7 +21,7 @@ use vars qw($VERSION);
 use constant DEFAULT_CACHE_TTL => 3600;
 use strict;
 
-$VERSION = 0.22;
+$VERSION = 0.23;
 
 =pod
 
@@ -414,7 +414,7 @@ sub _get {
 
     } else {
         $response = $self->ua->mirror($url, $file, $ttl);
-        eval { $data = decode_json(read_file($file)) };
+        eval { $data = decode_json(scalar(read_file($file))) };
 
     }
 
